@@ -5,6 +5,7 @@
     if (!any(facts))
         return(NULL)
     mf <- mf[, facts, drop = FALSE]
+    mf <- droplevels(mf)
     if (missing(wt)) 
         wt <- rep(1, nrow(mf))
     ind <- seq_len(nrow(mf))
@@ -16,13 +17,12 @@
     pnam <- labels(tmp)
     out <- NULL
     if (ncol(x) == 1) {
-        for(i in 1:length(tmp)) {
-            names(tmp[[i]]) <- paste(pnam[i], names(tmp[[i]]), sep="")
-            out <- c(out, tmp[[i]])
-            out <- matrix(out, nrow=1, dimnames = list(NULL, names(out)))
-        }  
+        nm <- unlist(sapply(pnam,
+                            function(nm) paste(nm, names(tmp[[nm]]), sep="")),
+                     use.names=FALSE)
+        out <- matrix(unlist(tmp), nrow=1, dimnames = list(NULL, nm))
     } else {
-        for (i in 1:length(tmp)) {
+        for (i in seq_along(tmp)) {
             colnames(tmp[[i]]) <- paste(pnam[i], colnames(tmp[[i]]), 
                                         sep = "")
             out <- cbind(out, tmp[[i]])
