@@ -1,5 +1,5 @@
 `factorfit` <-
-    function (X, P, permutations = 0, strata = NULL, w,  ...) 
+    function (X, P, permutations = 0, strata = NULL, w,  ...)
 {
     P <- as.data.frame(P)
     ## Check that all variables are factors, and coerce if necessary
@@ -7,7 +7,7 @@
         P <- data.frame(lapply(P, function(x)
                         if (is.factor(x)) x else factor(x)))
     P <- droplevels(P) ## make sure only the used levels are present
-    if (any(!sapply(P, is.factor))) 
+    if (any(!sapply(P, is.factor)))
         stop("All non-numeric variables must be factors")
     NR <- nrow(X)
     NC <- ncol(X)
@@ -19,7 +19,7 @@
     r <- NULL
     pval <- NULL
     totvar <- .C("goffactor", as.double(X), as.integer(rep(0, NR)),
-                 as.double(w), as.integer(NR), as.integer(NC), as.integer(1), 
+                 as.double(w), as.integer(NR), as.integer(NC), as.integer(1),
                  double(1), double(1), double(1), var = double(1), PACKAGE = "vegan")$var
     sol <- centroids.cca(X, P, w)
     var.id <- rep(names(P), sapply(P, nlevels))
@@ -27,12 +27,12 @@
     permat <- getPermuteMatrix(permutations, NR, strata = strata)
     permutations <- nrow(permat)
 
-    for (i in 1:length(P)) {
+    for (i in seq_along(P)) {
         A <- as.integer(P[[i]])
         NL <- nlevels(P[[i]])
         invar <- .C("goffactor", as.double(X), as.integer(A - 1), as.double(w),
-                    as.integer(NR), as.integer(NC), 
-                    as.integer(NL), double(NL), double(NL), double(NL), 
+                    as.integer(NR), as.integer(NC),
+                    as.integer(NL), double(NL), double(NL), double(NL),
                     var = double(1), PACKAGE = "vegan")$var
         r.this <- 1 - invar/totvar
         r <- c(r, r.this)
@@ -43,24 +43,24 @@
                 take <- A[indx]
                 invar <- .C("goffactor", as.double(X),
                             as.integer(take -  1), as.double(w),
-                            as.integer(NR), as.integer(NC), 
-                            as.integer(NL), double(NL), double(NL), double(NL), 
+                            as.integer(NR), as.integer(NC),
+                            as.integer(NL), double(NL), double(NL), double(NL),
                             var = double(1), PACKAGE = "vegan")$var
                 1 - invar/totvar
             }
-            tmp <- sapply(1:permutations,
+            tmp <- sapply(seq_len(permutations),
                           function(indx,...) ptest(permat[indx,], ...))
             pval.this <- (sum(tmp >= r.this) + 1)/(permutations + 1)
             pval <- c(pval, pval.this)
         }
     }
-    if (is.null(colnames(X))) 
+    if (is.null(colnames(X)))
         colnames(sol) <- paste("Dim", 1:ncol(sol), sep = "")
     else colnames(sol) <- colnames(X)
     names(r) <- names(P)
-    if (!is.null(pval)) 
+    if (!is.null(pval))
         names(pval) <- names(P)
-    out <- list(centroids = sol, r = r, permutations = permutations, 
+    out <- list(centroids = sol, r = r, permutations = permutations,
                 pvals = pval, var.id = var.id)
     out$control <- attr(permat, "control")
     class(out) <- "factorfit"
