@@ -3,11 +3,13 @@
              type = c("response", "working"), ...)
 {
     model <- match.arg(model)
+    if (is.null(object[[model]]))
+        stop("component ", model, " does not exist")
     type <- match.arg(type)
     ## Return scaled eigenvalues
     U <- switch(model,
-                CCA = object$CCA$u.eig,
-                CA = object$CA$u.eig,
+                CCA = object$CCA$u %*% diag(sqrt(object$CCA$eig)),
+                CA = object$CA$u %*% diag(sqrt(object$CA$eig)),
                 Imaginary = object$CA$imaginary.u.eig,
                 pCCA = object$pCCA$Fit/object$adjust)
     ## Distances or working scores U
