@@ -1,6 +1,6 @@
-"renyi" <-
-function (x, scales = c(0, 0.25, 0.5, 1, 2, 4, 8, 16, 32, 64, 
-    Inf), hill = FALSE) 
+`renyi` <-
+    function (x, scales = c(0, 0.25, 0.5, 1, 2, 4, 8, 16, 32, 64, 
+                 Inf), hill = FALSE) 
 {
     x <- as.matrix(x)
     n <- nrow(x)
@@ -17,8 +17,8 @@ function (x, scales = c(0, 0.25, 0.5, 1, 2, 4, 8, 16, 32, 64,
     for (a in 1:m) {
         if (scales[a] != 0 && scales[a] != 1 && scales[a] != 
             Inf) {
-            result[, a] <- log(apply(x^scales[a], 1, 
-                  sum))/(1 - scales[a])
+            result[, a] <- log(apply(x^scales[a], 1, sum))/(1 - 
+                                                            scales[a])
         }
         else {
             if (scales[a] == 0) {
@@ -36,7 +36,7 @@ function (x, scales = c(0, 0.25, 0.5, 1, 2, 4, 8, 16, 32, 64,
         result <- exp(result)
     result <- as.data.frame(result)
     if (any(dim(result) == 1)) 
-        result <- unlist(result, use.names = FALSE)
+        result <- unlist(result, use.names = TRUE)
+    class(result) <- c("renyi", class(result))
     result
 }
-
