@@ -91,14 +91,16 @@
         }
     }
     ## Take care that scores have names
-    for (i in 1:length(sol)) {
-        if (is.matrix(sol[[i]])) 
-            rownames(sol[[i]]) <-
-                rownames(sol[[i]], do.NULL = FALSE, 
-                         prefix = substr(names(sol)[i], 1, 3))
+    if (length(sol)) {
+        for (i in seq_along(sol)) {
+            if (is.matrix(sol[[i]])) 
+                rownames(sol[[i]]) <-
+                    rownames(sol[[i]], do.NULL = FALSE, 
+                             prefix = substr(names(sol)[i], 1, 3))
+        }
     }
     ## Only one type of scores: return a matrix instead of a list
     if (length(sol) == 1) 
         sol <- sol[[1]]
-    return(sol)
+    sol
 }
