@@ -95,7 +95,7 @@
     }
     ## Take care that scores have names
     if (length(sol)) {
-        for (i in 1:length(sol)) {
+        for (i in seq_along(sol)) {
             if (is.matrix(sol[[i]])) 
                 rownames(sol[[i]]) <-
                     rownames(sol[[i]], do.NULL = FALSE, 
@@ -109,5 +109,5 @@
     if (identical(const[1], const[2]))
         const <- const[1]
     attr(sol, "const") <- const
-    return(sol)
+    sol
 }
